@@ -19,7 +19,7 @@ Task::BeLike::RWP - Perl modules bundle to install from CPAN
 
 =head1 VERSION
 
-version 0.231740
+version 0.231750
 
 =head1 SYNOPSIS
 
@@ -33,63 +33,77 @@ The following Perl modules will be installed as part of this bundle.
 
 =over 4
 
+=item L<Path::Tiny> (L<GitHub|https://github.com/dagolden/Path-Tiny>)
 
-
-=back
-
-= L<Path::Tiny> (L<GitHub|https://github.com/dagolden/Path-Tiny>)
 OOP file management
 
-= L<System::Command> (L<GitHub|https://github.com/book/System-Command>)
+=item L<System::Command> (L<GitHub|https://github.com/book/System-Command>)
+
 Execute commands in OOP style
 
-= L<Net::DNS> (L<GitHub|https://github.com/NLnetLabs/Net-DNS>)
+=item L<Net::DNS> (L<GitHub|https://github.com/NLnetLabs/Net-DNS>)
+
 OOP DNS resolver and the rest
 
-= L<Dist::Zilla> (L<GitHub|https://github.com/rjbs/Dist-Zilla>)
+=item L<Dist::Zilla> (L<GitHub|https://github.com/rjbs/Dist-Zilla>)
+
 Perl distribution management and release
 
-= L<Config::General> (L<GitHub|https://github.com/TLINDEN/Config-General>)
+=item L<Config::General> (L<GitHub|https://github.com/TLINDEN/Config-General>)
+
 General configuration file parser
 
-= L<DBI> (L<GitHub|https://github.com/perl5-dbi/dbi>)
+=item L<DBI> (L<GitHub|https://github.com/perl5-dbi/dbi>)
+
 Database connection and manipulation
 
-= L<SQL::Abstract> (L<GitHub|https://github.com/dbsrgits/sql-abstract>)
+=item L<SQL::Abstract> (L<GitHub|https://github.com/dbsrgits/sql-abstract>)
+
 SQL command abstraction in OOP style with useful statement costructing methods
 
-= L<URI> (L<GitHub|https://github.com/libwww-perl/URI>)
+=item L<URI> (L<GitHub|https://github.com/libwww-perl/URI>)
+
 General URI class to handle URL's and the like
 
-= L<Clipboard> (L<GitHub|https://github.com/shlomif/Clipboard>)
+=item L<Clipboard> (L<GitHub|https://github.com/shlomif/Clipboard>)
+
 Cross-platform clipboard management
 
-= L<PadWalker> (L<GitHub|https://github.com/robinhouston/PadWalker>)
+=item L<PadWalker> (L<GitHub|https://github.com/robinhouston/PadWalker>)
+
 Supported by Perl Debugger as the C<y> command
 
-= L<Data::Printer> (L<GitHub|https://github.com/garu/Data-Printer>)
+=item L<Data::Printer> (L<GitHub|https://github.com/garu/Data-Printer>)
+
 Aids in debugging by displaying Perl data structures
 
-= L<Log::Log4perl> (L<GitHub|https://github.com/mschilli/log4perl>)
+=item L<Log::Log4perl> (L<GitHub|https://github.com/mschilli/log4perl>)
+
 Perl logging framework
 
-= L<IO::Tee> (L<GitHub|https://github.com/neilb/IO-Tee>)
+=item L<IO::Tee> (L<GitHub|https://github.com/neilb/IO-Tee>)
+
 Tee file handle
 
-= L<Domain::PublicSuffix> (L<GitHub|https://github.com/nmelnick/domain-publicsuffix>)
+=item L<Domain::PublicSuffix> (L<GitHub|https://github.com/nmelnick/domain-publicsuffix>)
+
 Get to the domain root, by Mozilla
 
-= L<Net::IP::XS> (L<GitHub|https://github.com/tomhrr/p5-Net-IP-XS>)
+=item L<Net::IP::XS> (L<GitHub|https://github.com/tomhrr/p5-Net-IP-XS>)
+
 IP class
 
-= L<XML::RSS> (L<GitHub|https://github.com/shlomif/perl-XML-RSS>)
+=item L<XML::RSS> (L<GitHub|https://github.com/shlomif/perl-XML-RSS>)
+
 RSS parser. Requires the C<libexpat1-dev> package to be installed.
 
-= L<Yaml::XS> (L<GitHub|https://github.com/ingydotnet/yaml-libyaml-pm>>)
+=item L<Yaml::XS> (L<GitHub|https://github.com/ingydotnet/yaml-libyaml-pm>>)
 
-= L<Rex>= (L<GitHub|https://github.com/RexOps/Rex>)
+=item L<Rex> (L<GitHub|https://github.com/RexOps/Rex>)
 
-= L<Number::Bytes::Human> (L<GitHub|https://github.com/aferreira/cpan-Number-Bytes-Human)
+=item L<Number::Bytes::Human> (L<GitHub|https://github.com/aferreira/cpan-Number-Bytes-Human)
+
+=back
 
 =head1 AUTHOR
 
